Jim Lindley
Developer · Not a member
Jim Lindley's latest activity
Saturday, August 09 2008
564
dangerous float operations
was updated
in Ruby on Rails
-
Jim Lindley commented at 9:58 PMTomasz,
There's more info on the details here, but isak is right - storage of floating point numbers in binary representation is less accurate then you'd think...
756
Nested fields_for doesn't work when passed name of field
was updated
in Ruby on Rails
785
Caching models fails in development
was updated
in Ruby on Rails
-
Jim Lindley commented at 9:26 PMMaybe dup objects before storing them, and then dup them on retrieval and return the copies to prevent tainting the cache?
Dup is even faster then marshal.
-
-
Jim Lindley commented at 5:27 PMOh wait, my math was based off reloading strings. It's worse then I thought in my previous comment, sorry.
-
Jim Lindley commented at 5:25 PMSome quick and dirty micro-benchmarking: http://gist.github.com/4683
Basically, marshaling is 20x slower to save and 100x slower to load.
However, Marshalling...